Package: GroupSeq
Title: Group Sequential Design Probabilities - With Graphical User
        Interface
Version: 1.4.3
Authors@R: 
    person("Roman", "Pahl",
    email = "roman.pahl@gmail.com", role = c("aut", "cre"))
Description: Computes probabilities related to group sequential designs for
    normally distributed test statistics. Enables to derive critical
    boundaries, power, drift, and confidence intervals of such designs.
    Supports the alpha spending approach by Lan-DeMets (1994)
    <doi:10.1002/sim.4780131308>.
Imports: tcltk, tcltk2, mvtnorm
Suggests: knitr, tinytest, rmarkdown, ggplot2, gridExtra
VignetteBuilder: knitr
License: GPL-3
URL: https://rpahl.github.io/GroupSeq/
BugReports: https://github.com/rpahl/GroupSeq/issues
NeedsCompilation: no
Author: Roman Pahl [aut, cre]
Maintainer: Roman Pahl <roman.pahl@gmail.com>
Repository: CRAN
RoxygenNote: 7.2.1
Encoding: UTF-8
Packaged: 2024-02-03 13:09:23 UTC; Roman
Date/Publication: 2024-02-03 16:30:02 UTC
Built: R 4.2.3; ; 2024-02-03 17:54:38 UTC; unix
